@@ -1,54 +1,33 @@
-from enum import Enum, auto
+from cosmoglobe.utils.functions import brightness_to_thermodynamical
 
-import astropy.units as u
 import numpy as np
-
-import cosmoglobe.utils.functions as F
-
-class CompState(Enum):
-    """State of a model component."""
-
-    ENABLED = auto()
-    DISABLED = auto()
-
-
+import astropy.units as u
 class NsideError(Exception):
-    """Raised if there is a NSIDE related problem."""
-
+    """Raised if there is a NSIDE related problem"""
+    pass
 
 class ModelError(Exception):
-    """Raised if there is a Model related problem."""
+    """Raised if there is a Model related problem"""
+    pass
 
 
-def extract_scalars(spectral_parameters):
-    """Extracts scalars from a spectral_parameter dict.
-    
-    If a map is constant in all dims, then it is converted to a (ndim,) 
-    array.
-    """
-
+def _extract_scalars(spectral_parameters):
+    """Extracts scalars from a spectral_parameter dict. If a map is constant
+    in all dims, then it is converted to a (ndim,) array"""
     scalars = {}
     for key, value in spectral_parameters.items():
-        if not isinstance(value, u.Quantity):
-            value = u.Quantity(value, unit=u.dimensionless_unscaled)
         if value.size > 1:
-            if value.ndim > 1:
-                uniques = [np.unique(col) for col in value.value]
-                all_is_unique = all([len(col) == 1 for col in uniques])
-            else:
-                uniques = np.unique(value.value)
-                all_is_unique = len(uniques) == 1
+            uniques = [np.unique(col) for col in value.value]
+            all_is_unique = all([len(col) == 1 for col in uniques])
             if all_is_unique:
                 scalars[key] = uniques*value.unit
+
         else:
             scalars[key] = value
-
     return scalars
 
 
-def set_spectral_units(maps):
-    """Sets the spectral value for a specific spectral parameter name."""
-
+def _set_spectral_units(maps):
     #TODO: Figure out how to correctly detect unit of spectral map in chain.
     #      Until then, a hardcoded dict is used:
     units = dict(
@@ -65,12 +44,7 @@ def set_spectral_units(maps):
     return maps
 
 
-def str_to_astropy_unit(unit):
-    """Converts a K_RJ or a K_CMB string to `u.K` unit.
-    
-    This function preserves the prefix.
-    """
-
+def _str_to_astropy_unit(unit):
     try:
         output_unit = u.Unit(unit)
     except ValueError:
@@ -84,19 +58,6 @@ def str_to_astropy_unit(unit):
 
 
 def emission_to_unit(emission, freqs, unit):
-    """Converts the unit of the emission.
-    
-    Parameters
-    ----------
-    emission : `astropy.quantity.Quantity`
-        Emission whos unit we want to convert.
-    freqs : `astropy.quantity.Quantity`
-        Frequency or a list of frequencies for which the emission was 
-        obtained.
-    unit : `astropy.UnitBase`
-        Unit to convert to.
-    """
-
     try:
         unit = u.Unit(unit)
         emission = emission.to(
@@ -108,7 +69,8 @@ def emission_to_unit(emission, freqs, unit):
             unit = u.Unit(unit[:-3])
         elif unit.lower().endswith('k_cmb'):
             unit = u.Unit(unit[:-4])  
-            emission *= F.brightness_to_thermodynamical(freqs)
+            print("here")
+            emission *= brightness_to_thermodynamical(freqs)
         emission.to(unit)
 
     return emission
@@ -117,17 +79,12 @@ def emission_to_unit(emission, freqs, unit):
 def gaussian_beam_2D(r, sigma):
     """Returns the Gaussian beam in 2D in polar coordinates.
 
-    Parameters
-    ----------
+    Parameters:
+    -----------
     r : float
         Angular distance.
     sigma : float
         The sigma of the Gaussian (beam radius).
-
-    Returns
-    -------
-    `numpy.array_like`
-        Gaussian beam.
+    
     """
-
-    return r*np.exp(-(r**2)/(2 * sigma**2))/(sigma*np.sqrt(2*np.pi))
\ No newline at end of file
+    return r*np.exp(-(r**2)/(2 * sigma**2))/(sigma*np.sqrt(2*np.pi))
